summary refs log tree commit diff
path: root/arch
diff options
context:
space:
mode:
authorJianxun Zhang <jianxun.zhang@intel.com>2019-02-20 13:50:42 -0800
committerchrome-bot <chrome-bot@chromium.org>2019-03-01 23:41:40 -0800
commit96f2d8ebe2b2523ed2ca0cf54005ded8d9cd8e4f (patch)
tree6ca9b383840b91c9f53cefbf02a12dfb64596085 /arch
parent1a6262bd97d100f455bb01a41c1f3784e3ca143e (diff)
downloadcrosvm-96f2d8ebe2b2523ed2ca0cf54005ded8d9cd8e4f.tar
crosvm-96f2d8ebe2b2523ed2ca0cf54005ded8d9cd8e4f.tar.gz
crosvm-96f2d8ebe2b2523ed2ca0cf54005ded8d9cd8e4f.tar.bz2
crosvm-96f2d8ebe2b2523ed2ca0cf54005ded8d9cd8e4f.tar.lz
crosvm-96f2d8ebe2b2523ed2ca0cf54005ded8d9cd8e4f.tar.xz
crosvm-96f2d8ebe2b2523ed2ca0cf54005ded8d9cd8e4f.tar.zst
crosvm-96f2d8ebe2b2523ed2ca0cf54005ded8d9cd8e4f.zip
linux: rename function of device creation
Rename functions and parameters that had 'virtio' in their names
because we also create non-virtio devices like audio.

BUG=none
TEST=emerge-eve crosvm and deploy it to the device, verify some of
devices are still created at /sys/bus/virtio/devices/

Change-Id: I3ea75159a865e5f00ecef349725b3c12f94afaca
Signed-off-by: Jianxun Zhang <jianxun.zhang@intel.com>
Reviewed-on: https://chromium-review.googlesource.com/1480739
Commit-Ready: ChromeOS CL Exonerator Bot <chromiumos-cl-exonerator@appspot.gserviceaccount.com>
Tested-by: kokoro <noreply+kokoro@google.com>
Reviewed-by: David Tolnay <dtolnay@chromium.org>
Reviewed-by: Zach Reizner <zachr@chromium.org>
Diffstat (limited to 'arch')
-rw-r--r--arch/src/lib.rs4
1 files changed, 2 insertions, 2 deletions
diff --git a/arch/src/lib.rs b/arch/src/lib.rs
index 2560ff5..4596ee2 100644
--- a/arch/src/lib.rs
+++ b/arch/src/lib.rs
@@ -76,11 +76,11 @@ pub trait LinuxArch {
     ///
     /// * `components` - Parts to use to build the VM.
     /// * `split_irqchip` - whether to use a split IRQ chip (i.e. userspace PIT/PIC/IOAPIC)
     /// * `virtio_devs` - Function to generate a list of virtio devices.
     fn build_vm<F>(
         components: VmComponents,
         split_irqchip: bool,
-        virtio_devs: F,
+        create_devices: F,
     ) -> Result<RunnableLinuxVm>
     where
         F: FnOnce(
@@ -76,11 +76,11 @@ pub trait LinuxArch {
     /// * `components` - Parts to use to build the VM.
     /// * `split_irqchip` - whether to use a split IRQ chip (i.e. userspace PIT/PIC/IOAPIC)
-    /// * `virtio_devs` - Function to generate a list of virtio devices.
+    /// * `create_devices` - Function to generate a list of devices.
     fn build_vm<F>(
         components: VmComponents,